from radio_bridge.radio_bridge import startRadioBridge
import uvloop, asyncio, signal, os, sys
import argparse
import configparser
from pathlib import Path

def ask_exit(*args):
    STOP.set()

def ask_restart(*args):
    Path('/tmp/cnq-radio-bridge-restart').touch()
    RESTART.set()

def changeCPUAffinity():
    affinity = os.sched_getaffinity(0)
    print("Process is eligible to run on CPU cores:", affinity)

    affinity_mask = {max(affinity)} #get highest CPU core
    os.sched_setaffinity(0, affinity_mask)

    affinity = os.sched_getaffinity(0)
    print("Now process is eligible to run on CPU core:", affinity)

if __name__ == '__main__':
    uvloop.install()
    loop = asyncio.get_event_loop()

    STOP = asyncio.Event()
    RESTART = asyncio.Event()

    loop.add_signal_handler(signal.SIGINT, ask_exit)
    loop.add_signal_handler(signal.SIGTERM, ask_exit)
    loop.add_signal_handler(signal.SIGHUP, ask_restart)


    parser = argparse.ArgumentParser()
    parser.add_argument('--networkId', default=10, type=int, help='The network ID from 0 to 255')
    parser.add_argument('--nodeId', default=1, type=int, help='The node ID from 0 to 254')

    args = parser.parse_args()

    parser = configparser.ConfigParser()

    parser.read_dict({
    'MQTT': {'host': 'localhost', 'port': '1883', 'keepalive': '60'},
    'UART': {'device': '/dev/ttyS2', 'speed': '500000'},
    'TIME': {'sync-interval': '1860', 'ntp-check-interval-min': '5', 'ntp-check-interval-max': '300'},
    'RADIO': {'rssi-threshold': '-98'},
    'LOG': {'sensor-rtc-offset': 'false', 'failed-decrypt': 'true'}
    })

    parser.read("/etc/cnq-radio-bridge")

    rssiThreshold = parser['RADIO'].getint('rssi-threshold')

    print("RSSI threshold {}".format(rssiThreshold))

    if rssiThreshold >= 0:
        print("RSSI threshold must be negative")
        sys.exit(1)


    restartIndicator = Path('/tmp/cnq-radio-bridge-restart')
    isRestarting = restartIndicator.is_file()

    if isRestarting:
        restartIndicator.unlink()

    #changeCPUAffinity()

    try:
        loop.run_until_complete(startRadioBridge(args, parser, loop, STOP, RESTART, isRestarting))
    finally:
        loop.close()
